@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Wrapper::Net_Telnet;
 {
-  $Net::CLI::Interact::Transport::Wrapper::Net_Telnet::VERSION = '2.130880';
+  $Net::CLI::Interact::Transport::Wrapper::Net_Telnet::VERSION = '2.131260';
 }
 
 use Moo;
@@ -37,9 +37,19 @@ sub pump {
 }
 
 has '+timeout' => (
-    trigger => quote_sub(q{(shift)->wrapper->timeout(shift) if scalar @_ > 1}),
+    trigger => 1,
 );
 
+sub _trigger_timeout {
+    my $self = shift;
+    if (scalar @_) {
+        my $timeout = shift;
+        if ($self->connect_ready) {
+            $self->wrapper->timeout($timeout);
+        }
+    }
+}
+
 has '+wrapper' => (
     isa => InstanceOf['Net::Telnet'],
 );
